<?php

namespace Icinga\Module\Director\Clicommands;

use Icinga\Module\Director\Cli\ObjectCommand;

/**
 * Manage Icinga Servicegroups
 *
 * Use this command to show, create, modify or delete Icinga Servicegroups
 * objects
 */
class ServiceGroupCommand extends ObjectCommand
{
}
